# remirepo spec file for php-phpiredis
#
# Copyright (c) 2016-2024 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%scl_package         php-phpiredis
%endif

%bcond_without     tests

%global gh_commit  4b6e81fc73b9473123a353c7c71112bf66a420ae
%global gh_short   %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner   nrk
%global gh_project phpiredis

%global pecl_name  phpiredis
%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%if "%{php_version}" < "5.6"
%global ini_name   %{pecl_name}.ini
%else
%global ini_name   40-%{pecl_name}.ini
%endif
%global sources    %{gh_project}-%{gh_commit}
%global _configure ../%{sources}/configure

Name:           %{?scl_prefix}php-%{pecl_name}
Version:        1.0.1
Release:        7%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}

Summary:        Client extension for Redis

License:        BSD-2-Clause
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{pecl_name}-%{version}-%{gh_short}.tar.gz

# Fix build with hiredis >= 0.14
# https://github.com/nrk/phpiredis/pull/67
Patch0:         %{pecl_name}-pr67.patch

BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel
BuildRequires:  %{?scl_prefix}php-pear
# ensure we use hiredis-last when exists
BuildRequires:  hiredis-devel >= 0.13.3
%if %{with tests}
BuildRequires:  valkey
%endif

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}


%description
Phpiredis is an extension for PHP based on hiredis
that provides a simple and efficient client for Redis and a fast
incremental parser / serializer for the RESP protocol.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

cd %{sources}
%patch -P0 -p1 -b .pr67

# Check extension version
ver=$(sed -n '/define PHP_PHPIREDIS_VERSION/{s/.* "//;s/".*$//;p}' php_phpiredis.h)
if test "$ver" != "%{version}%{?prever}%{?gh_date:-dev}"; then
   : Error: Upstream VERSION version is ${ver}, expecting %{version}%{?prever}%{?gh_date:-dev}.
   exit 1
fi
cd ..

cat  << 'EOF' | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure --with-php-config=%{__phpconfig}
%make_build

%if %{with_zts}
cd ../ZTS
%configure --with-php-config=%{__ztsphpconfig}
%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install configuration
install -Dpm 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
%make_install -C ZTS
install -Dpm 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif


%check
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with_zts}
: Minimal load test for NTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif

%if %{with tests}
: Run test server
cd %{sources}
pidfile=$PWD/valkey.pid
port=$(%{__php} -r 'echo 9000 + PHP_MAJOR_VERSION*100 + PHP_MINOR_VERSION*10 + PHP_INT_SIZE;')
sed -e "/REDIS_PORT/s/6379/$port/" -i tests/testsuite_configuration.inc
mkdir -p data

valkey-server                   \
    --bind      127.0.0.1      \
    --port      $port          \
    --daemonize yes            \
    --logfile   $PWD/valkey.log \
    --dir       $PWD/data      \
    --pidfile   $pidfile


: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff || ret=1

: Cleanup
if [ -s $pidfile ]; then
   kill $(cat $pidfile)
   sleep 1
fi

exit $ret
%endif


%files
%license %{sources}/LICENSE
%doc %{sources}/README.md

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Nov 18 2024 Remi Collet <remi@remirepo.net> - 1.0.1-7
- use valkey for tests

* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 1.0.1-6
- rebuild for PHP 8.3.0RC1

* Fri Jul  7 2023 Remi Collet <remi@remirepo.net> - 1.0.1-5
- build out of sources tree

* Tue Jan 18 2022 Remi Collet <remi@remirepo.net> - 1.0.1-4
- add patch for hiredis 1.0.2 from
  https://github.com/nrk/phpiredis/pull/67

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 1.0.1-3
- rebuild for 8.1.0RC1

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 1.0.1-2
- rebuild for PHP 8.0.0RC1

* Mon Sep 21 2020 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1
- drop patch marged upstream

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 1.0.0-19
- rebuild for PHP 8.0.0beta3

* Mon Aug 24 2020 Remi Collet <remi@remirepo.net> - 1.0.0-18
- add patch for PHP 8 from
  https://github.com/nrk/phpiredis/pull/66

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 1.0.0-13
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 1.0.0-12
- rebuild for 7.4.0beta1

* Tue Dec  4 2018 Remi Collet <remi@remirepo.net> - 1.0.0-11
- EL-build with test suite temporarily disabled

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 1.0.0-10
- rebuild for 7.3.0beta2 new ABI

* Thu Jul 26 2018 Remi Collet <remi@remirepo.net> - 1.0.0-9
- rebuild

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 1.0.0-8
- rebuild for 7.3.0alpha4 new ABI

* Wed Jun 27 2018 Remi Collet <remi@remirepo.net> - 1.0.0-7
- cleanup

* Tue Oct  3 2017 Remi Collet <remi@remirepo.net> - 1.0.0-6
- F27: release bump

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 1.0.0-3
- rebuild for PHP 7.2.0beta1 new API

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-2
- rebuild with PHP 7.1.0 GA

* Thu Nov 24 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-1
- update to 1.0.0 release

* Sun Nov 13 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-0.2.20160715gita64e3bf
- add minor fix for portability
- add full reflection for all functions
- open https://github.com/nrk/phpiredis/pull/53

* Sat Nov 12 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-0.1.20160715gita64e3bf
- Initial packaging of 1.0.0-dev

